Exception: Horologium::ConfigurationError
- Defined in:
- lib/horologium/error.rb,
sig/horologium.rbs
Overview
Raised when the configuration is changed after it has been frozen, or given something it cannot use. The configuration is set once, inside configure, and locked afterwards.